---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**

```
[ Include a code snippet that produces your bug. Make it standalone, we should be able to run it. ]

[ Include a data sample or link to your data if necessary to run the code ]

```

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment (please complete the following information):**
 - Browser [e.g. chrome, firefox]
 - Jupyter Notebook or html files?
 - Python version (check it with `import sys; print(sys.version_info)`)
 - folium version (check it with `import folium; print(folium.__version__)`)
 - branca version (check it with `import branca; print(branca.__version__)`)

**Additional context**
Add any other context about the problem here.

**Possible solutions**
List any solutions you may have come up with.

folium is maintained by volunteers. Can you help making a fix for this issue?
